# Benchmarks

This directory contains benchmark results generated by the GitHub Actions workflow.

## Auto-generated by benchmark-action

The benchmark HTML files are automatically generated and pushed to this directory.
